You can install API JS library using `npm` or add it to project's dependencies. See [Readme](https://github.com/Adamant-im/adamant-api-jsclient) for reference.

```sh
npm install adamant-api
```

Initialize the library, passing list of ADAMANT nodes and log object. It's better to initialize API library in a separate module `api.js`, and then refer to it.

``` js
// api.js
const adamantApi = require('adamant-api');
const customLogger = require('./logger.js');

const nodesList = [
  'http://localhost:36666',
  'https://endless.adamant.im',
  'https://clown.adamant.im',
  'http://23.226.231.225:36666',
  'http://88.198.156.44:36666',
  'https://lake.adamant.im'
];

const callback = () => console.log(
    'ADAMANT API is ready to use!'
);

const options = {
  node: nodesList,
  logLevel: 'info',
  checkHealthAtStartup: true // default
};

module.exports = adamantApi(options, customLogger, callback);
```

List of ADAMANT nodes `node` is an array including nodes you want to connect.

Object `customLogger` is used to log current operations. It must implement `error`, `info`, `warn` an `log` methods. See an [example](https://github.com/Adamant-im/adamant-exchangebot/blob/master/helpers/log.js). If no logger provided, the library uses the system console.

The `callback` function is a callback that will be called after initialization and health check if `options.checkHealthAtStartup` is not `false`. It also can be set using the `setStartupCallback` method:

```js
api.setStartupCallback(() => {
  // ...
})
```

The library will use verbosity according to `logLevel` parameter: it can be `none` < `error` < `warn` < `info` < `log`.

Then refer to JS API in other modules:

``` js
// file blockChecker.js
const api = require('./api');

api.get('blocks').then(response => {
  console.log(response.data)
})
```

If you want to use [WebSocket connections](https://github.com/Adamant-im/adamant/wiki/REST-and-Socket-connections), initialize socket:

``` js
// file app.js
const api = require('./api');

api.socket.initSocket({
  socket: true,
  wsType: 'ws',
  onNewMessage: txParser,
  admAddress: 'U6386412615727665758'
});
```

Set `socket` to true to activate socket connections. Param `wsType` is one of "ws" or "wss", depending on your host.

Function `onNewMessage` will be executed when new transaction appears for given `admAddress` with transaction object passed. In this example, `txParser(transaction)` will be called.
